sparseinv-package: sparseinv

sparseinv-packageR Documentation

sparseinv

Description

This package creates a wrapper for the SuiteSparse routines in C that use the Takahashi equations to compute the elements of the inverse of a sparse matrix at locations where the (permuted) Cholesky factor is structurally non-zero. The resulting matrix is known as a sparse inverse subset. Some helper functions (like the permuted Cholesky factorisation) are also implemented. Support for spam matrices is currently limited and will be implemented in the future.

Author(s)

Maintainer: Andrew Zammit-Mangion andrewzm@gmail.com

Other contributors:


sparseinv documentation built on July 21, 2026, 1:06 a.m.