symb: Return the symbolic representation of a Matrix

View source: R/fns.R

symbR Documentation

Return the symbolic representation of a Matrix

Description

This function takes an object of class Matrix and returns the same Matrix with all elements replaced with 1 #'

Usage

symb(A)

Arguments

A

object of class Matrix

Value

object of class Matrix

Examples

require(Matrix)
Q = sparseMatrix(i = c(1, 1, 2, 2),
                 j = c(1, 2, 1, 2),
                 x = c(0.1, 0.2, 0.2, 1))
Qsymb <- symb(Q)
Qsymb

sparseinv documentation built on July 21, 2026, 1:06 a.m.