| sparseinv-package | R Documentation |
This package creates a wrapper for the SuiteSparse routines in C that use the Takahashi equations to compute the elements of the inverse of a sparse matrix at locations where the (permuted) Cholesky factor is structurally non-zero. The resulting matrix is known as a sparse inverse subset. Some helper functions (like the permuted Cholesky factorisation) are also implemented. Support for spam matrices is currently limited and will be implemented in the future.
Maintainer: Andrew Zammit-Mangion andrewzm@gmail.com
Other contributors:
Timothy Davis davis@tamu.edu [contributor]
Patrick Amestoy Patrick.Amestoy@enseeiht.fr [contributor]
Iain Duff iain.duff@stfc.ac.uk [contributor]
John K. Reid John.Reid@stfc.ac.uk [contributor]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.