| symb | R Documentation |
This function takes an object of class Matrix and returns the same Matrix with all elements replaced with 1 #'
symb(A)
A |
object of class Matrix |
object of class Matrix
require(Matrix)
Q = sparseMatrix(i = c(1, 1, 2, 2),
j = c(1, 2, 1, 2),
x = c(0.1, 0.2, 0.2, 1))
Qsymb <- symb(Q)
Qsymb
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.